#
# spec file for package pympress
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# The reverse-dns-like string used as app id and desktop file name
%define gtk_app_id io.github.pympress
# Do not support python 2, and build a single package
%define pythons python3
Name:           pympress
Version:        1.8.6
Release:        1.1
Summary:        A simple and powerful dual-screen PDF reader designed for presentations
License:        GPL-2.0-or-later
URL:            https://github.com/Cimbali/pympress/
Source0:        %{url}/releases/download/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  coreutils
BuildRequires:  fdupes
BuildRequires:  findutils
BuildRequires:  gettext
BuildRequires:  gobject-introspection
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Sphinx
BuildRequires:  python3-myst-parser
BuildRequires:  python3-pip
BuildRequires:  python3-setuptools >= 42
BuildRequires:  python3-wheel
BuildRequires:  sed
Requires:       gobject-introspection
Requires:       gstreamer
Requires:       gstreamer-plugins-base
Requires:       gstreamer-plugins-good
Requires:       gstreamer-plugins-good-gtk
Requires:       gtk3
Requires:       python3-gobject
Requires:       python3-watchdog
Requires:       python(abi) >= 3.4
Requires:       typelib(DBus)
Requires:       typelib(DBusGLib)
Requires:       typelib(GLib)
Requires:       typelib(GObject)
Requires:       typelib(Gdk)
Requires:       typelib(GdkPixbuf)
Requires:       typelib(Gio)
Requires:       typelib(Gst)
Requires:       typelib(GstAllocators)
Requires:       typelib(GstApp)
Requires:       typelib(GstAudio)
Requires:       typelib(GstVideo)
Requires:       typelib(Gtk)
Requires:       typelib(Poppler)
Requires:       typelib(cairo)
Requires(post): permissions
Recommends:     gstreamer-plugins-bad
Recommends:     gstreamer-plugins-ugly
Recommends:     typelib(GstBadAudio)
Recommends:     typelib(GstCodecs)
Recommends:     typelib(GstMpegts)
Recommends:     typelib(GstWebRTC)
BuildArch:      noarch
%if %{python_version_nodots} < 39
Requires:       python3-importlib-resources
%endif

%description
Pympress is a PDF presentation tool designed for dual-screen setups such as
presentations and public talks.

Highly configurable, fully-featured, and portable, pympress comes with many
great features, including:
- supports embedded gifs, video, and audio
- text annotations displayed in the presenter window
- natively supports beamer's “notes on second screen”, as well as Libreoffice
  notes pages
- and much more

%prep
%autosetup

%build
%pyproject_wheel

# Build docs using options to skip devel docs (modules autodoc) which are in pympress.md and require resources that must be downloaded
# (sphinx extensions, intersphinx mappings from linked docs, etc), as well as installing instructions.
%python_exec -m sphinx -b html -d build/doctrees -Dskip_api_doc=1 -Dpackaged_docs=1 docs/ html/
%python_exec -m sphinx -b man  -d build/doctrees -Dskip_api_doc=1 -Dpackaged_docs=1 docs/ man/

%install
%pyproject_install

# Identify lang files
%find_lang pympress

mkdir -p %{buildroot}%{_mandir}/man1/
cp -av man/pympress.1 %{buildroot}%{_mandir}/man1/

# Also install docs to get them covered by fdupes
mkdir -p "%{buildroot}%{_defaultdocdir}/%{name}"
mv html/* "%{buildroot}%{_defaultdocdir}/%{name}/"

# Hardlink duplicate files, typically X.pyc and X.opt-1.pyc and pympress.png under /usr/share
# keep this specific so we still raise errors if we add a file twice
find "%{buildroot}%{python3_sitelib}/pympress/" -type d -name __pycache__ | xargs -L1 %fdupes
%fdupes "%{buildroot}%{_datadir}"

%post
%set_permissions %{_bindir}/pympress

# An old version distributed through copr listed files but not directories as installed files
# if upgrading, make sure to clean up these directories otherwise python is confused about what’s installed
if [ $1 -gt 1 ]; then
find "%{python3_sitelib}" -maxdepth 1 -name 'pympress-1.5.*' -print0 | xargs -0 --no-run-if-empty rm -r
fi

%files -f pympress.lang

# sitelib directories
%{python3_sitelib}/%{name}
%{python3_sitelib}/%{name}-%{version}.dist-info

# out-of-sitelib files
%{_datadir}/applications/%{gtk_app_id}.desktop
%{_datadir}/pixmaps/%{name}.png
%verify(not mode) %attr(0755, root, root) %{_bindir}/pympress

# doc
%{_defaultdocdir}/%{name}
%{_mandir}/man1/%{name}.*
%license LICENSE.txt

%changelog
* Tue Jul 22 2025 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.8.6:
  * Fix building process on newer setuptools.
  * Fix layout overview bug.
  * Fix layout editing bug.
  * Fix pointer mode activation bug.
  * Fix media positioning issues.
  * Updated translations.
  * Update documentation with newer install processes and
    correcting typos.
- Use full Url for Source0.
- Drop use of deprecated macro %%suse_update_desktop_file.
* Fri Dec 15 2023 me@cimba.li
-   Update to v1.8.5
  * Include missing standard PDF fonts on Windows, which caused
    pdfs that don't include fonts (e.g. images from ggplot2) to
    have symbols that were not rendered
  * Fix high-DPI (scaling ≥ 200%%) blurriness on Windows
  * document and improve error messaging for Gstreamer's Gtk
    plugin dependency (libgstgtk)
* Thu Sep  7 2023 me@cimba.li
-   Update to v1.8.4
  * Fix bug in v1.8.3 where translations were not being found
  * Update Italian and Polish translations
  * Avoid inconsequential errors on exit
* Tue Jun  6 2023 me@cimba.li
-   Update to v1.8.3
  * Various improvements to drawing tool:
  * improve smoothness,
  * widen range of line widths (in particular thinner lines),
  * support stylus pen pressure
  * allow setting width on eraser drawing tool
  * support stylus eraser tip
  * Increase traditional chinese translation coverage
* Mon Jun  5 2023 me@cimba.li
-   Update to v1.8.3b Beta of drawings with eraser fixed
* Mon Jun  5 2023 me@cimba.li
-   Update to v1.8.3a Alpha-release of scribble changes
* Tue Apr  4 2023 me@cimba.li
- Update to v1.8.2
  * Fix resource importing issues on python 3.8 and 3.9
* Sat Mar 25 2023 me@cimba.li
-   Update to v1.8.1
  * improve packaged docs appearance and coherence
  * update latest translations (chinese)
  * fix monitor handling on wayland: fullscreen-on-start only
    instead of crashing \#283, do not attempt to move windows
    as we can't
  * fix importlib.resources issue which caused crashes on older
    python versions \#282
  * only save window size if not maximised
  * do not attempt to start fullscreen if we detect i3 wm \#282
* Wed Mar 15 2023 me@cimba.li - 1.8.0
- Automatic full-screen of the content window on your non-primay
  screen when connecting a 2nd screen, or extending the desktop to
  a 2nd screen if both screens were mirrored.
- A “deck overview” widget that allows to see all slides and
  click the desired one for fast access
- Improved media support, including no visual artefacts when
  playing embedded audio files, and support for media start
  position and duration.
* Tue Dec  7 2021 me@cimba.li - 1.7.1
- Fix building process
- Fix errors in compiling catalogs with gettext during build
  process
* Mon Nov 22 2021 me@cimba.li - 1.7.0
- Make “next slide” a grid of 1-16 next slides
- Allow dynamic layout editing from pympress (rather than modifying
  the config file manually)
- Make annotations editable
- Allow to save modified PDF files
- Automatic next slide and looping
- Support auto-play (some annotations, e.g. movie15 / ConTeXt)
- Make gstreamer default media backend on macOS and Linux
- Limit to python 3.4+ to do some code modernization
* Sat Aug 14 2021 me@cimba.li - 1.6.4
  Avoid pip version parsing bug when installing
- setup.py: fix setuptools version parsing (#208) by Jörg Thalheim
* Sat Jul 31 2021 me@cimba.li - 1.6.3
  Fix packages and gstreamer video
- Some packages were missing translation files
- Added cleanup of directories that pympress 1.5 RPMs left around
  (causing pympress to fail to start ater update, #194)
- Update the `gstreamer` backend to play videos for more stability
  (should work on all platforms provided gstreamer is installed)
* Thu Jul 22 2021 me@cimba.li - 1.6.2
  Fix path handling
  Caused bugs in file watching (#203) and media playing (#197).
- Add some keywords to .desktop file (#205) by Christopher Hoskin
- surfacecache: update docs to match code, clarify glib idle
  sourcefunc (#201) by wisp3rwind
* Sat May 15 2021 me@cimba.li - 1.6.1
  Fix small bugs in 1.6 release
- fix some PDF links not working
- improve screensaver handling
- include compiled translation catalogs (.mo files) on pypi
- cleaner log files
- complete and correct various distribution metadata
* Fri Apr 16 2021 me@cimba.li - 1.6.0
  Release v1.6.0
- Support LibreOffice-style notes pages, after slides pages
- Add support for drawing on slides with various presets and an
  eraser preset
- Add command-line control of pympress, thanks to Gtk.Application
  single-instance ability
- Ensure file handles of closed files are released through early
  garbage collection
- Various improvements in binary (rpm / msi) releases
- Fix rendering bugs on scaled displays and with embedded fonts
- Update README (#182) by Fernando Tricas García
- typo: notes notes -> notes (#175) by Hörmet Yiltiz
- mention libreoffice in the main page (#174) by Hörmet Yiltiz
- Render to Cairo image surfaces (#169) by Daniel Wilson
- Update aur package name (#166) by Nils Ziermann
* Fri Apr 10 2020 me@cimba.li - 1.5.3
  Accessibility improvements, bug fixes, new “big” button
- Reduce noise in log
- Add big button to toggle pointer off <-> {manual or always}
- Improve automatic builds (for RPM and Windows)
- Exit gracefully (save prefs, return 0, etc.) on interrupt
- Fix text getting inserted in wrong locations
- Properly clean up (watchdog objects, windows) for interactive
  sessions
- Simplify annotations display for braille accessibility
- Build rpms automatically (#141)
* Thu Feb  6 2020 me@cimba.li - 1.5.2
  This release brings a number of convenience fixes, nothing that
  should affect a lot of people.
- End of python 2 support
- `.desktop` file (and icon) now installed via pip, so users can
  have access to pympress without console
- Some css improvements, especially for macOS users where the
  background overriding the theme’s settings caused poor contrast
- Less jumpy layout for width-constrained screens
- Bug fix restoring the access to the timing breakdown
- Make timing breakdown window scrollable
- Locales update
- Fix man page number
- Name translators in documentation
- Other docs updates
- More freedesktop-compliant way to disable the screensaver, which
  means it also works on Wayland
- Distribute zips for windows for portable versions
- Fix incorrect document member access (#139) by Steffen Klee
- Add Screensaving on Wayland (#131) by Tim Klocke
- Fix spellings (#130) by Christopher Hoskin
- Move man page from Section 6 to Section 1 (#129) by Christopher
  Hoskin
* Thu Nov 28 2019 me@cimba.li - 1.5.1
  Update release mechanisms, for Homebrew and building for Windows
  via appveyor.
* Mon Nov 25 2019 me@cimba.li - 1.5.0
  A handful of new features, mainly centered around configuration
  files and video support:
- Portable configurations, supported by ticking
  `Starting Configuration` > `Portable installation`
  This requires write permissions in the root install directory of
  pympress.
- All keyboard shortcuts are configurable in the config file.
- Support for Gstreamer as a video backend rather than VLC
- Configuration file locations now respect platform-specific
  conventions better
- Log file locations also respect platform-specific conventions and
  are written to user locations to avoid problems with multi-user
  systems
- Options for both video backends to enable/disable, set
  initialization options, and choose applicable mime types.
- Blank background colour can be black or white (`white_blanking`
  option under `[content]` in the configuration file)
- Configuration file `pympress/share/defaults.conf` containing
  default/fallback values.
  This file should not be modified by the user.
- The laser pointer can now be switched on continuously
- Add 'continous mode' for laser pointer (#121) by Vulpeculus
- Add log file path the the Help > About dialog (#118) by Johannes
  Reiff
- Fix the log filename for multi-user systems (#117) by Johannes
  Reiff
- Describe installation from Chocolatey package (#112)
* Wed Aug 14 2019 me@cimba.li - 1.4.1
  Give more visibility to the logo
  Automated upload of windows binaries, more logo visibility.
* Wed Aug  7 2019 me@cimba.li - 1.4.0
  Presentation time analysis and automated building for windows
- Fix for #103 (#104) by walli545
* Thu Feb  7 2019 me@cimba.li - 1.3.1
- Add pygobject3 to brew requirements (#97) by Paolo G. Giarrusso
* Sat Jan 26 2019 me@cimba.li - 1.3.0
- Update German translation (#95) by FriedrichFröbel
- Update of Czech translation (#94) by multiflexi
- Spanish translation update (#93) by Suso Comesaña
* Thu Sep  6 2018 me@cimba.li - 1.2.0
  Gif support and other novelties
- Pympress now supports playing gif files that are embedded as
  movies, e.g. with `\movie` in the multimedia package for beamer.
- The highlight mode is now configurable just like the normal and
  notes on second screen modes, meaning we can see notes together
  with the current slide being highlighted.
- Czech translation (courtesy of @multiflexi )
- Translation update (#75)
- Czech translation (#74) by multiflexi
- minor typo (#65) by Pablo Rodríguez
- Update German translations (#55) by FriedrichFröbel
* Tue Jan 16 2018 me@cimba.li - 1.1.2
  Bugfix Small patch to fix the estimated talk time
* Sun Jan  7 2018 me@cimba.li - 1.1.1
  Improve video support on two screens
* Fri Dec  1 2017 me@cimba.li - 1.1.0
* Thu Aug 10 2017 me@cimba.li - 1.0.4
  Novelties:
- Possibility to rearrange layout in config file (see here for how
  the constraints on the json string's content:
  https://pympress.github.io/options.html#layouts),
- ctrl + click now emulates a laser pointer on screen,
- various bug fixes,
- menu of recently opened files,
- any errors now are logged to a file named pympress.log in the
  current directory
- Renamed messages.mo to LC_MESSAGES/pympress.mo (#30) by Stanisław
  Polak
- Add polish translation for 'Open Recent" (#29)
- Internalize all translations with python gettext (#21)
* Thu Mar 23 2017 me@cimba.li - 1.0.2
  Should fix prerendering issues on Windows
* Fri Mar  3 2017 me@cimba.li - 1.0.1
- Fix osx i18n (#17)
- Add German translation (#16) by FriedrichFröbel
* Mon Jan 30 2017 me@cimba.li - 1.0
- Refactor to load widgets from glade xml files (#4)
- Scribble (#3)
- Suggestions (#2) by Epithumia
- Some old and some new (#1) by Christof Rath
